Class: Cinch::Plugin::ClassMethods::Timer

Inherits:
Struct
  • Object
show all
Defined in:
lib/cinch/plugin.rb

Overview

Note:

This is not the same as a Timer object, which will allow controlling and inspecting actually running timers. This class only describes a Timer that still has to be created.

Represents a Timer as created by #timer.

Instance Attribute Summary collapse

Instance Attribute Details

#interval ⇒ Numeric

Returns the current value of interval.

Returns:

  • (Numeric) —

    the current value of interval



110
111
112
# File 'lib/cinch/plugin.rb', line 110

def interval
  @interval
end

#options ⇒ Hash

Returns the current value of options.

Returns:

  • (Hash) —

    the current value of options



110
111
112
# File 'lib/cinch/plugin.rb', line 110

def options
  @options
end

#registered ⇒ Boolean

Returns the current value of registered.

Returns:

  • (Boolean) —

    the current value of registered



110
111
112
# File 'lib/cinch/plugin.rb', line 110

def registered
  @registered
end